@@ -67,6 +67,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
         client_cert_source_for_mtls: Callable[[], Tuple[bytes, bytes]] = None,
         quota_project_id: Optional[str] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+        always_use_jwt_access: Optional[bool] = False,
     ) -> None:
         """Instantiate the transport.
 
@@ -89,16 +90,16 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -107,6 +108,8 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
 
         Raises:
           google.auth.exceptions.MutualTLSChannelError: If mutual TLS transport
@@ -160,6 +163,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             scopes=scopes,
             quota_project_id=quota_project_id,
             client_info=client_info,
+            always_use_jwt_access=always_use_jwt_access,
         )
 
         if not self._grpc_channel:
@@ -215,14 +219,14 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
               and ``credentials_file`` are passed.
         """
 
-        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
-
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
             quota_project_id=quota_project_id,
-            **self_signed_jwt_kwargs,
+            default_scopes=cls.AUTH_SCOPES,
+            scopes=scopes,
+            default_host=cls.DEFAULT_HOST,
             **kwargs,
         )
 
@@ -413,6 +417,36 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             )
         return self._stubs["retry_build"]
 
+    @property
+    def approve_build(
+        self,
+    ) -> Callable[[cloudbuild.ApproveBuildRequest], operations_pb2.Operation]:
+        r"""Return a callable for the approve build method over gRPC.
+
+        Approves or rejects a pending build.
+        If approved, the returned LRO will be analogous to the
+        LRO returned from a CreateBuild call.
+
+        If rejected, the returned LRO will be immediately done.
+
+        Returns:
+            Callable[[~.ApproveBuildRequest],
+                    ~.Operation]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "approve_build" not in self._stubs:
+            self._stubs["approve_build"] = self.grpc_channel.unary_unary(
+                "/google.devtools.cloudbuild.v1.CloudBuild/ApproveBuild",
+                request_serializer=cloudbuild.ApproveBuildRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["approve_build"]
+
     @property
     def create_build_trigger(
         self,
@@ -614,17 +648,14 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def create_worker_pool(
         self,
-    ) -> Callable[[cloudbuild.CreateWorkerPoolRequest], cloudbuild.WorkerPool]:
+    ) -> Callable[[cloudbuild.CreateWorkerPoolRequest], operations_pb2.Operation]:
         r"""Return a callable for the create worker pool method over gRPC.
 
-        Creates a ``WorkerPool`` to run the builds, and returns the new
-        worker pool.
-
-        This API is experimental.
+        Creates a ``WorkerPool``.
 
         Returns:
             Callable[[~.CreateWorkerPoolRequest],
-                    ~.WorkerPool]:
+                    ~.Operation]:
                 A function that, when called, will call the underlying RPC
                 on the server.
         """
@@ -636,7 +667,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["create_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/CreateWorkerPool",
                 request_serializer=cloudbuild.CreateWorkerPoolRequest.serialize,
-                response_deserializer=cloudbuild.WorkerPool.deserialize,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_worker_pool"]
 
@@ -646,9 +677,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     ) -> Callable[[cloudbuild.GetWorkerPoolRequest], cloudbuild.WorkerPool]:
         r"""Return a callable for the get worker pool method over gRPC.
 
-        Returns information about a ``WorkerPool``.
-
-        This API is experimental.
+        Returns details of a ``WorkerPool``.
 
         Returns:
             Callable[[~.GetWorkerPoolRequest],
@@ -671,16 +700,14 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def delete_worker_pool(
         self,
-    ) -> Callable[[cloudbuild.DeleteWorkerPoolRequest], empty_pb2.Empty]:
+    ) -> Callable[[cloudbuild.DeleteWorkerPoolRequest], operations_pb2.Operation]:
         r"""Return a callable for the delete worker pool method over gRPC.
 
-        Deletes a ``WorkerPool`` by its project ID and WorkerPool name.
-
-        This API is experimental.
+        Deletes a ``WorkerPool``.
 
         Returns:
             Callable[[~.DeleteWorkerPoolRequest],
-                    ~.Empty]:
+                    ~.Operation]:
                 A function that, when called, will call the underlying RPC
                 on the server.
         """
@@ -692,23 +719,21 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["delete_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/DeleteWorkerPool",
                 request_serializer=cloudbuild.DeleteWorkerPoolRequest.serialize,
-                response_deserializer=empty_pb2.Empty.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["delete_worker_pool"]
 
     @property
     def update_worker_pool(
         self,
-    ) -> Callable[[cloudbuild.UpdateWorkerPoolRequest], cloudbuild.WorkerPool]:
+    ) -> Callable[[cloudbuild.UpdateWorkerPoolRequest], operations_pb2.Operation]:
         r"""Return a callable for the update worker pool method over gRPC.
 
-        Update a ``WorkerPool``.
-
-        This API is experimental.
+        Updates a ``WorkerPool``.
 
         Returns:
             Callable[[~.UpdateWorkerPoolRequest],
-                    ~.WorkerPool]:
+                    ~.Operation]:
                 A function that, when called, will call the underlying RPC
                 on the server.
         """
@@ -720,7 +745,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["update_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/UpdateWorkerPool",
                 request_serializer=cloudbuild.UpdateWorkerPoolRequest.serialize,
-                response_deserializer=cloudbuild.WorkerPool.deserialize,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["update_worker_pool"]
 
@@ -732,9 +757,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     ]:
         r"""Return a callable for the list worker pools method over gRPC.
 
-        List project's ``WorkerPools``.
-
-        This API is experimental.
+        Lists ``WorkerPool``\ s.
 
         Returns:
             Callable[[~.ListWorkerPoolsRequest],
